
#if defined(LV_LVGL_H_INCLUDE_SIMPLE)
#include "lvgl.h"
#elif defined(LV_LVGL_H_INCLUDE_SYSTEM)
#include <lvgl.h>
#elif defined(LV_BUILD_TEST)
#include "../lvgl.h"
#else
#include "lvgl/lvgl.h"
#endif

#ifndef LV_ATTRIBUTE_MEM_ALIGN
#define LV_ATTRIBUTE_MEM_ALIGN
#endif

#ifndef LV_ATTRIBUTE_TEST_ARGB8888_RLE_ALIGN64
#define LV_ATTRIBUTE_TEST_ARGB8888_RLE_ALIGN64
#endif

static const
LV_ATTRIBUTE_MEM_ALIGN LV_ATTRIBUTE_LARGE_CONST LV_ATTRIBUTE_TEST_ARGB8888_RLE_ALIGN64
uint8_t test_ARGB8888_RLE_align64_map[] = {

    0x01,0x00,0x00,0x00,0x30,0x30,0x00,0x00,0x80,0x43,0x00,0x00,0x47,0x00,0xff,0x00,
    0xff,0x83,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0xff,0x00,0x00,0x00,0x00,0x44,0x00,
    0x00,0x00,0x00,0x84,0x00,0xff,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0xff,
    0x00,0x00,0x00,0x00,0x44,0x00,0x00,0x00,0x00,0x96,0x00,0xff,0x00,0xff,0x00,0x00,
    0x00,0x00,0x00,0xff,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,
    0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0xff,0xff,
    0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
    0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x00,0x00,
    0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x11,0x00,0x00,0xff,0xff,0xff,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0xff,0x00,
    0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x00,
    0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,
    0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
    0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
    0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x3f,0xff,0x00,0x00,0x96,0xff,0x00,0x00,
    0xd6,0xff,0x00,0x00,0xf9,0xff,0x00,0x00,0xf9,0xff,0x00,0x00,0xd6,0xff,0x00,0x00,
    0x96,0xff,0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0xff,0x00,
    0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x00,
    0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,
    0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
    0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
    0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0x00,
    0x1a,0xff,0x00,0x00,0x93,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,
    0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,
    0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0x93,0xff,0x00,0x00,0x1a,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x6a,0xff,0x00,0x00,0xdf,0xff,0x00,0x00,
    0xdf,0xff,0x00,0x00,0x6a,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0x00,0xff,0xff,0x00,0x00,
    0x00,0x00,0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,
    0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,
    0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,
    0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0xff,
    0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0x00,
    0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,
    0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
    0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
    0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x1a,0xff,0x00,
    0x00,0xa7,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,
    0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,
    0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xa7,0xff,0x00,
    0x00,0x1a,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0x00,0xdf,0xff,0x00,0x00,0xff,0xff,0x00,
    0x00,0xff,0xff,0x00,0x00,0xdf,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x00,0x00,
    0x00,0x00,0x00,0x00,0xff,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0xff,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0xff,
    0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0x00,
    0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,
    0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
    0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
    0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x93,0xff,0x00,
    0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,
    0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,
    0x00,0xff,0xff,0x00,0x00,0xff,0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,
    0x00,0x00,0x93,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0x00,0xdf,0xff,0x00,0x00,0xff,0xff,
    0x00,0x00,0xff,0xff,0x00,0x00,0xdf,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x00,
    0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x00,
    0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,
    0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,
    0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0xff,0x00,0x00,0x00,0x00,0x00,
    0xff,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,
    0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,
    0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0xff,0xff,0xff,0xff,0xff,
    0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
    0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x3f,0xff,0x00,0x00,0xff,0xff,
    0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,
    0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,
    0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,
    0x00,0x00,0xff,0xff,0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x6a,0xff,0x00,0x00,0xdf,0xff,
    0x00,0x00,0xdf,0xff,0x00,0x00,0x6a,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x00,
    0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x00,
    0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0xff,0x00,0x00,0x00,0x00,0x00,
    0xff,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,
    0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,
    0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0xff,0xff,0xff,0xff,0xff,
    0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
    0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x96,0xff,0x00,0x00,0xff,
    0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,
    0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,
    0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,
    0xff,0x00,0x00,0xff,0xff,0x00,0x00,0x96,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,
    0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,
    0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,
    0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,
    0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0xff,0x00,0x00,0x00,0x00,
    0x00,0xff,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,
    0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,
    0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0xff,0xff,0xff,0xff,
    0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
    0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0x00,0xd6,0xff,0x00,0x00,0xff,
    0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,
    0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,
    0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,
    0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xd6,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,
    0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,
    0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,
    0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0xff,0x00,0x00,0x00,0x00,
    0xff,0x00,0xff,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,
    0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
    0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x00,0x00,0x00,
    0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,
    0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0x00,0xf9,0xff,0x00,0x00,
    0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,
    0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,
    0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,
    0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xf9,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x40,0xff,0x00,0x00,0xac,0xff,0x00,0x00,
    0xf2,0xff,0x00,0x00,0xf2,0xff,0x00,0x00,0xac,0xff,0x00,0x00,0x40,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,
    0xff,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0xff,
    0xff,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0xff,
    0xff,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0xff,
    0xff,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0xff,
    0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0xff,0x00,0x00,0x00,
    0x00,0x00,0xff,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0xff,
    0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
    0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x00,0x00,0x00,
    0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,
    0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0x00,0xf9,0xff,0x00,0x00,
    0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,
    0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,
    0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,
    0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xf9,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0xff,0x00,0x00,0x40,0xff,0x00,0x00,0xd3,0xff,0x00,0x00,0xff,0xff,0x00,0x00,
    0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xd3,0xff,0x00,0x00,
    0x40,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,
    0xff,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x00,0x00,0x00,0x00,0xff,0x00,0x00,
    0xff,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x00,0x00,0x00,0x00,0x00,0x00,
    0xff,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x00,0x00,0x00,0x00,0x00,0x00,
    0xff,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0xff,0x00,0x00,
    0x00,0x00,0x00,0xff,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,
    0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
    0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x00,0x00,
    0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,
    0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0x00,0xd6,0xff,0x00,
    0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,
    0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,
    0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,
    0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xd6,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0xff,0x00,0x00,0xac,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,
    0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,
    0x00,0xac,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0xff,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x00,0x00,0x00,0x00,0x00,0x00,
    0xff,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,
    0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0x00,0x00,0x00,0x00,
    0xff,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x00,0x00,0x00,0x00,0x00,0x00,
    0xff,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0xff,0x00,0x00,
    0x00,0x00,0x00,0xff,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,
    0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
    0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x00,0x00,
    0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,
    0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x96,0xff,0x00,
    0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,
    0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,
    0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,
    0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0x96,0xff,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0xff,0x00,0x00,0xf2,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,
    0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,
    0x00,0x00,0xf2,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0xff,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x00,0x00,0x00,0x00,0x00,
    0x00,0xff,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0xff,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x00,0x00,0x00,0x00,0x00,
    0x00,0xff,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0xff,0x00,
    0x00,0x00,0x00,0x00,0xff,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,
    0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
    0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x00,
    0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,
    0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x3f,0xff,
    0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,
    0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,
    0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,
    0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0xff,0x00,0x00,0xf2,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,
    0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,
    0x00,0x00,0xf2,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0xff,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x00,0x00,0x00,0x00,0x00,
    0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,
    0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,
    0x00,0xff,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x00,0x00,0x00,0x00,0x00,
    0x00,0xff,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0xff,0x00,
    0x00,0x00,0x00,0x00,0xff,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,
    0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
    0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0x00,
    0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,
    0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0xff,0x00,0x00,0x93,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,
    0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,
    0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,
    0xff,0x00,0x00,0xff,0xff,0x00,0x00,0x93,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0xff,0x00,0x00,0xac,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,
    0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,
    0xff,0x00,0x00,0xac,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0xff,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x00,0x00,0x00,0x00,
    0x00,0x00,0xff,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0xff,
    0x00,0x00,0x00,0x00,0x00,0xff,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
    0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
    0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,
    0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0xff,0x00,0x00,0x1a,0xff,0x00,0x00,0xa7,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,
    0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,
    0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,
    0xff,0x00,0x00,0xa7,0xff,0x00,0x00,0x1a,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x40,0xff,0x00,0x00,0xd3,0xff,0x00,0x00,0xff,
    0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xd3,
    0xff,0x00,0x00,0x40,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0xff,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,
    0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,
    0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,
    0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0x00,0x00,
    0x00,0x00,0xff,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0xff,
    0x00,0x00,0x00,0x00,0x00,0xff,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0xff,0xff,0xff,0xff,0xc6,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
    0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,
    0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,
    0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,
    0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x1a,0xff,0x00,0x00,0x93,0xff,0x00,0x00,
    0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,
    0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,
    0x93,0xff,0x00,0x00,0x1a,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x40,0xff,0x00,0x00,
    0xac,0xff,0x00,0x00,0xf2,0xff,0x00,0x00,0xf2,0xff,0x00,0x00,0xac,0xff,0x00,0x00,
    0x40,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0xff,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0xff,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,
    0xff,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0xff,0x00,0x00,0x00,0x00,0x18,0x00,0x00,
    0x00,0x00,0xb0,0xff,0x00,0x00,0x3f,0xff,0x00,0x00,0x96,0xff,0x00,0x00,0xd6,0xff,
    0x00,0x00,0xf9,0xff,0x00,0x00,0xf9,0xff,0x00,0x00,0xd6,0xff,0x00,0x00,0x96,0xff,
    0x00,0x00,0x3f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,
    0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,
    0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,
    0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,
    0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0xff,0xff,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0xff,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0xff,0x00,
    0x00,0x00,0x00,0x44,0x00,0x00,0x00,0x00,0x84,0x00,0xff,0x00,0xff,0x00,0x00,0x00,
    0x00,0x00,0xff,0x00,0xff,0x00,0x00,0x00,0x00,0x44,0x00,0x00,0x00,0x00,0x98,0x00,
    0xff,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0xff,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x12,0x00,0x00,0x00,0x28,0x00,
    0x00,0x00,0x33,0x00,0x00,0x00,0x26,0x00,0x00,0x00,0x08,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x2e,
    0x00,0x00,0x00,0xff,0x95,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,
    0xff,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x35,0x00,0x00,0x00,
    0x95,0x00,0x00,0x00,0xdd,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,
    0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xfa,0x00,0x00,0x00,0xc4,0x00,0x00,0x00,
    0x5c,0x00,0x00,0x00,0x01,0x00,0x00,0x00,0x00,0x35,0x00,0x00,0x00,0x00,0x94,0x00,
    0xff,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0xff,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xb2,0x00,0x00,0x00,0xff,0x00,
    0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,
    0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,
    0x00,0x00,0xff,0x00,0x00,0x00,0xbb,0x00,0x00,0x00,0x0b,0x00,0x00,0x00,0x00,0x34,
    0x00,0x00,0x00,0x00,0x94,0x00,0xff,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0xff,0x00,
    0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0xe9,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,
    0xff,0x00,0x00,0x00,0xfe,0x00,0x00,0x00,0xfa,0x00,0x00,0x00,0xff,0x00,0x00,0x00,
    0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,
    0xa9,0x00,0x00,0x00,0x00,0x34,0x00,0x00,0x00,0x00,0x95,0x00,0xff,0x00,0xff,0x00,
    0x00,0x00,0x00,0x00,0xff,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0xe5,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,
    0x00,0x00,0xe5,0x00,0x00,0x00,0x49,0x00,0x00,0x00,0x09,0x00,0x00,0x00,0x03,0x00,
    0x00,0x00,0x3c,0x00,0x00,0x00,0xdd,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,
    0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0x2b,0x00,0x00,0x00,0x00,0x33,
    0x00,0x00,0x00,0x00,0xa5,0x00,0xff,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0xff,0x00,
    0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0xe1,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xa3,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x44,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,
    0xff,0x00,0x00,0x00,0x6f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x14,0x00,0x00,0x00,0x76,0x00,0x00,0x00,
    0xbb,0x00,0x00,0x00,0xdd,0x00,0x00,0x00,0xe6,0x00,0x00,0x00,0xd3,0x00,0x00,0x00,
    0x9e,0x00,0x00,0x00,0x37,0x00,0x00,0x00,0x00,0x23,0x00,0x00,0x00,0x00,0xa6,0x00,
    0xff,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0xff,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xbe,0x00,0x00,0x00,0xdc,0x00,
    0x00,0x00,0xdc,0x00,0x00,0x00,0x6b,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x09,0x00,0x00,0x00,0xff,0x00,
    0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0x89,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x53,0x00,
    0x00,0x00,0xf8,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,
    0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xfe,0x00,
    0x00,0x00,0x7b,0x00,0x00,0x00,0x00,0x22,0x00,0x00,0x00,0x00,0xa7,0x00,0xff,0x00,
    0xff,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x0e,0x00,0x00,0x00,0x14,0x00,0x00,0x00,0x14,0x00,0x00,0x00,0xff,0x00,0x00,0x00,
    0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0x90,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x6c,0x00,0x00,0x00,
    0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xe0,0x00,0x00,0x00,0x8b,0x00,0x00,0x00,
    0x83,0x00,0x00,0x00,0xda,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,
    0xff,0x00,0x00,0x00,0x37,0x00,0x00,0x00,0x00,0x21,0x00,0x00,0x00,0x00,0xa7,0x00,
    0xff,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0xff,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x00,
    0x00,0x00,0x52,0x00,0x00,0x00,0xa3,0x00,0x00,0x00,0xe2,0x00,0x00,0x00,0xfa,0x00,
    0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,
    0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0x90,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x68,0x00,
    0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0x40,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x13,0x00,0x00,0x00,0xf1,0x00,0x00,0x00,0xff,0x00,
    0x00,0x00,0xff,0x00,0x00,0x00,0x8c,0x00,0x00,0x00,0x00,0x14,0x00,0x00,0x00,0x00,
    0xb4,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0xff,0x00,
    0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x1d,0x00,0x00,0x00,0xca,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,
    0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,
    0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,
    0xff,0x00,0x00,0x00,0x90,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x41,0x00,0x00,0x00,0xa4,0x00,0x00,0x00,0xa4,0x00,0x00,0x00,
    0x12,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0xc5,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xa8,0x00,0x00,0x00,
    0x00,0x21,0x00,0x00,0x00,0x00,0xb4,0x00,0xff,0x00,0xff,0x00,0x00,0x00,0x00,0x00,
    0xff,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0d,0x00,
    0x00,0x00,0xdd,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,
    0x00,0x00,0xff,0x00,0x00,0x00,0xe7,0x00,0x00,0x00,0xc1,0x00,0x00,0x00,0xb8,0x00,
    0x00,0x00,0xb8,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,
    0x00,0x00,0xff,0x00,0x00,0x00,0x90,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x12,0x00,
    0x00,0x00,0x55,0x00,0x00,0x00,0x7a,0x00,0x00,0x00,0x8c,0x00,0x00,0x00,0x90,0x00,
    0x00,0x00,0xe4,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xac,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x14,0x00,0x00,0x00,0x5e,0x00,0x00,0x00,0x7e,0x00,0x00,0x00,0x6c,0x00,
    0x00,0x00,0x1e,0x00,0x00,0x00,0x00,0x14,0x00,0x00,0x00,0x00,0xb5,0x00,0xff,0x00,
    0xff,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x79,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,
    0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0x79,0x00,0x00,0x00,0x03,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x00,
    0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0x90,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x00,0x00,0x00,
    0x81,0x00,0x00,0x00,0xf7,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,
    0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,
    0xff,0x00,0x00,0x00,0xac,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x12,0x00,0x00,0x00,0xf7,0x00,0x00,0x00,0xfe,0x00,0x00,0x00,
    0xe1,0x00,0x00,0x00,0xfc,0x00,0x00,0x00,0xf9,0x00,0x00,0x00,0x42,0x00,0x00,0x00,
    0x00,0x13,0x00,0x00,0x00,0x00,0xfd,0x00,0xff,0x00,0xff,0x00,0x00,0x00,0x00,0x00,
    0xff,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xbb,0x00,
    0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xd4,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,
    0x00,0x00,0xff,0x00,0x00,0x00,0x90,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x82,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,
    0x00,0x00,0xff,0x00,0x00,0x00,0xbc,0x00,0x00,0x00,0x8d,0x00,0x00,0x00,0x88,0x00,
    0x00,0x00,0xe2,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xac,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x13,0x00,
    0x00,0x00,0xff,0x00,0x00,0x00,0x7e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x5d,0x00,
    0x00,0x00,0xff,0x00,0x00,0x00,0xb4,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0xff,0x00,0x00,0x00,0x00,0x00,
    0xff,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xd1,0x00,
    0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xc8,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x2a,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,
    0x00,0x00,0xff,0x00,0x00,0x00,0x90,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x03,0x00,0x00,0x00,0xf3,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,
    0x00,0x00,0x8e,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0xc0,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xac,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x00,
    0x00,0x00,0x22,0x00,0x00,0x00,0x49,0x00,0x00,0x00,0x61,0x00,0x00,0x00,0x84,0x00,
    0x00,0x00,0xff,0x00,0x00,0x00,0xcf,0x00,0x00,0x00,0x00,0x13,0x00,0x00,0x00,0x00,
    0xb5,0x00,0xff,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0xff,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xb5,0x00,0x00,0x00,0xff,0x00,0x00,0x00,
    0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0x70,0x00,0x00,0x00,
    0x18,0x00,0x00,0x00,0x1f,0x00,0x00,0x00,0x6c,0x00,0x00,0x00,0xec,0x00,0x00,0x00,
    0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,
    0x94,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x19,0x00,0x00,0x00,
    0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0x56,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x00,0x00,0x00,0xd4,0x00,0x00,0x00,
    0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xac,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x00,0x00,0x00,0xcc,0x00,0x00,0x00,
    0xff,0x00,0x00,0x00,0xde,0x00,0x00,0x00,0xd9,0x00,0x00,0x00,0xff,0x00,0x00,0x00,
    0xd0,0x00,0x00,0x00,0x00,0x13,0x00,0x00,0x00,0x00,0xfe,0x00,0xff,0x00,0xff,0x00,
    0x00,0x00,0x00,0x00,0xff,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x64,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,
    0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,
    0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,
    0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xfb,0x00,0x00,0x00,0xdc,0x00,
    0x00,0x00,0x4c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x07,0x00,0x00,0x00,0xf7,0x00,0x00,0x00,0xff,0x00,
    0x00,0x00,0xff,0x00,0x00,0x00,0xd4,0x00,0x00,0x00,0x58,0x00,0x00,0x00,0x5f,0x00,
    0x00,0x00,0xc5,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,
    0x00,0x00,0xc1,0x00,0x00,0x00,0x1f,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x6c,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xa4,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x30,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xd0,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0xff,0x00,
    0x00,0x00,0x00,0x00,0xff,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x04,0x00,0x00,0x00,0xc2,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,
    0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,
    0x00,0x00,0xff,0x00,0x00,0x00,0xb3,0x00,0x00,0x00,0xc5,0x00,0x00,0x00,0xff,0x00,
    0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,
    0x00,0x00,0x64,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x95,0x00,0x00,0x00,0xff,0x00,
    0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,
    0x00,0x00,0xff,0x00,0x00,0x00,0xe1,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,
    0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0x0c,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x64,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xd5,0x00,0x00,0x00,0x64,0x00,
    0x00,0x00,0xbe,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xdf,0x00,0x00,0x00,0x26,0x00,
    0x00,0x00,0x00,0x12,0x00,0x00,0x00,0x00,0xfa,0x00,0xff,0x00,0xff,0x00,0x00,0x00,
    0x00,0x00,0xff,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x0a,0x00,0x00,0x00,0x92,0x00,0x00,0x00,0xf6,0x00,0x00,0x00,
    0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xf3,0x00,0x00,0x00,
    0x83,0x00,0x00,0x00,0x05,0x00,0x00,0x00,0x72,0x00,0x00,0x00,0xff,0x00,0x00,0x00,
    0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,
    0x64,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x07,0x00,0x00,0x00,0x97,0x00,0x00,0x00,
    0xfa,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xeb,0x00,0x00,0x00,
    0x5c,0x00,0x00,0x00,0x60,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,
    0xff,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0x0c,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x09,0x00,0x00,0x00,0xbc,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0xfb,0x00,0x00,0x00,
    0x83,0x00,0x00,0x00,0xf9,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0x9c,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0xff,0x00,0x00,0x00,
    0x00,0x00,0xff,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0a,0x00,0x00,0x00,
    0x3b,0x00,0x00,0x00,0x4e,0x00,0x00,0x00,0x3c,0x00,0x00,0x00,0x0b,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x0e,0x00,0x00,0x00,0x37,0x00,0x00,0x00,0x31,0x00,0x00,0x00,0x06,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x14,0x00,0x00,0x00,0x0f,0x00,0x00,0x00,
    0x00,0x16,0x00,0x00,0x00,0x00,0x84,0x00,0xff,0x00,0xff,0x00,0x00,0x00,0x00,0x00,
    0xff,0x00,0xff,0x00,0x00,0x00,0x00,0x44,0x00,0x00,0x00,0x00,0xff,0x00,0xff,0x00,
    0xff,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0xf7,0xff,0x00,0xff,0xe5,0xff,0x00,0xff,0xd4,0xff,0x00,0xff,0xc3,0xff,0x00,
    0xff,0xb2,0xff,0x00,0xff,0xa0,0xff,0x00,0xff,0x90,0xff,0x00,0xff,0x7f,0xff,0x00,
    0xff,0x6e,0xff,0x00,0xff,0x5c,0xff,0x00,0xff,0x4b,0xff,0x00,0xff,0x3a,0xff,0x00,
    0xff,0x29,0xff,0x00,0xff,0x17,0xff,0x00,0xff,0x02,0xff,0x00,0xff,0x00,0xff,0x0f,
    0xff,0x00,0xff,0x20,0xff,0x00,0xff,0x31,0xff,0x00,0xff,0x43,0xff,0x00,0xff,0x54,
    0xff,0x00,0xff,0x64,0xff,0x00,0xff,0x76,0xff,0x00,0xff,0x87,0xff,0x00,0xff,0x98,
    0xff,0x00,0xff,0xa9,0xff,0x00,0xff,0xbb,0xff,0x00,0xff,0xcc,0xff,0x00,0xff,0xdd,
    0xff,0x00,0xff,0xee,0xff,0x00,0xff,0xff,0xff,0x00,0xff,0xff,0xff,0x00,0xff,0xff,
    0xff,0x00,0xff,0xff,0xff,0x00,0xff,0xff,0xfb,0x00,0xff,0xff,0xf2,0x00,0xff,0xff,
    0xe9,0x00,0xff,0xff,0xe1,0x00,0xff,0xff,0xd9,0x00,0xff,0xff,0xd0,0x00,0xff,0xff,
    0xc7,0x00,0xff,0xff,0xbf,0x00,0xff,0xff,0xb6,0x00,0xff,0xff,0xae,0x00,0xff,0xff,
    0xa5,0x00,0xff,0xff,0x9d,0x00,0xff,0xff,0x94,0x00,0xff,0xff,0x8c,0x00,0xff,0xff,
    0x83,0x00,0xff,0xff,0x7a,0x00,0xff,0xff,0x71,0x00,0xff,0xff,0x69,0x00,0xff,0xff,
    0x60,0x00,0xff,0xff,0x58,0x00,0xff,0xff,0x4f,0x00,0xff,0xff,0x47,0x00,0xff,0xff,
    0x3e,0x00,0xff,0xff,0x36,0x00,0xff,0xff,0x2d,0x00,0xff,0xff,0x25,0x00,0xff,0xff,
    0x1c,0x00,0xff,0xff,0x13,0x00,0xff,0xff,0x0b,0x00,0xff,0xff,0x02,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,0x00,
    0xff,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0xf7,0xff,0x00,0xff,0xe5,0xff,0x00,0xff,0xd4,0xff,0x00,0xff,0xc3,0xff,0x00,
    0xff,0xb2,0xff,0x00,0xff,0xa0,0xff,0x00,0xff,0x8f,0xff,0x00,0xff,0x7f,0xff,0x00,
    0xff,0x6e,0xff,0x00,0xff,0x5c,0xff,0x00,0xff,0x4b,0xff,0x00,0xff,0x3a,0xff,0x00,
    0xff,0x29,0xff,0x00,0xff,0x17,0xff,0x00,0xff,0x02,0xff,0x00,0xff,0x00,0xff,0x0f,
    0xff,0x00,0xff,0x20,0xff,0x00,0xff,0x31,0xff,0x00,0xff,0x42,0xff,0x00,0xff,0x54,
    0xff,0x00,0xff,0x64,0xff,0x00,0xff,0x76,0xff,0x00,0xff,0x87,0xff,0x00,0xff,0x98,
    0xff,0x00,0xff,0xa9,0xff,0x00,0xff,0xba,0xff,0x00,0xff,0xcb,0xff,0x00,0xff,0xdd,
    0xff,0x00,0xff,0xee,0xff,0x00,0xff,0xff,0xff,0x00,0xff,0xff,0xff,0x00,0xff,0xff,
    0xff,0x00,0xff,0xff,0xff,0x00,0xff,0xff,0xfb,0x00,0xff,0xff,0xf2,0x00,0xff,0xff,
    0xea,0x00,0xff,0xff,0xe1,0x00,0xff,0xff,0xd8,0x00,0xff,0xff,0xd0,0x00,0xff,0xff,
    0xc8,0x00,0xff,0xff,0xbe,0x00,0xff,0xff,0xb6,0x00,0xff,0xff,0xae,0x00,0xff,0xff,
    0xa5,0x00,0xff,0xff,0x9d,0x00,0xff,0xff,0x94,0x00,0xff,0xff,0x8b,0x00,0xff,0xff,
    0x83,0x00,0xff,0xff,0x7a,0x00,0xff,0xff,0x72,0xff,0x00,0xff,0xff,0x69,0x00,0xff,
    0xff,0x60,0x00,0xff,0xff,0x58,0x00,0xff,0xff,0x50,0x00,0xff,0xff,0x47,0x00,0xff,
    0xff,0x3e,0x00,0xff,0xff,0x35,0x00,0xff,0xff,0x2d,0x00,0xff,0xff,0x25,0x00,0xff,
    0xff,0x1c,0x00,0xff,0xff,0x13,0x00,0xff,0xff,0x0b,0x00,0xff,0xff,0x02,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,
    0x00,0xff,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0xf6,0xff,0x00,0xff,0xe5,0xff,0x00,0xff,0xd4,0xff,0x00,0xff,0xc3,0xff,
    0x00,0xff,0xb2,0xff,0x00,0xff,0xa1,0xff,0x00,0xff,0x8f,0xff,0x00,0xff,0x7f,0xff,
    0x00,0xff,0x6d,0xff,0x00,0xff,0x5c,0xff,0x00,0xff,0x4b,0xff,0x00,0xff,0x3a,0xff,
    0x00,0xff,0x29,0xff,0x00,0xff,0x17,0xff,0x00,0xff,0x02,0xff,0x00,0xff,0x00,0xff,
    0x0f,0xff,0x00,0xff,0x20,0xff,0x00,0xff,0x31,0xff,0x00,0xff,0x42,0xff,0x00,0xff,
    0x54,0xff,0x00,0xff,0x65,0xff,0x00,0xff,0x76,0xff,0x00,0xff,0x87,0xff,0x00,0xff,
    0x98,0xff,0x00,0xff,0xa9,0xff,0x00,0xff,0xba,0xff,0x00,0xff,0xcc,0xff,0x00,0xff,
    0xdd,0xff,0x00,0xff,0xee,0xff,0x00,0xff,0xff,0xff,0x00,0xff,0xff,0xff,0x00,0xff,
    0xff,0xff,0x00,0xff,0xff,0xff,0x00,0xff,0xff,0xfb,0x00,0xff,0xff,0xf2,0x00,0xff,
    0xff,0xe9,0x00,0xff,0xff,0xe1,0x00,0xff,0xff,0xd8,0x00,0xff,0xff,0xd0,0x00,0xff,
    0xff,0xc7,0x00,0xff,0xff,0xbe,0x00,0xff,0xff,0xb6,0x00,0xff,0xff,0xad,0x00,0xff,
    0xff,0xa5,0x00,0xff,0xff,0x9c,0x00,0xff,0xff,0x94,0x00,0xff,0xff,0x8b,0x00,0xff,
    0xff,0x83,0x00,0xff,0xff,0x7a,0x00,0xff,0xff,0x72,0x00,0xff,0xff,0x69,0x00,0xff,
    0xff,0x60,0x00,0xff,0xff,0x58,0x00,0xff,0xff,0x4f,0x00,0xff,0xff,0x47,0x00,0xff,
    0xff,0x3e,0x00,0xff,0xff,0x36,0x00,0xff,0xff,0x2d,0x00,0xff,0xff,0x24,0x00,0xff,
    0xff,0x1c,0x00,0xff,0xff,0x13,0x00,0xff,0xff,0x0b,0x00,0xff,0xff,0x02,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xff,
    0x00,0xff,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0xf7,0xff,0x00,0xff,0xe5,0xff,0x00,0xff,0xd4,0xff,0x00,0xff,0xc3,0xff,
    0x00,0xff,0xb2,0xff,0x00,0xff,0xa1,0xff,0x00,0xff,0x90,0xff,0x00,0xff,0x7e,0xff,
    0x00,0xff,0x6e,0xff,0x00,0xff,0x5c,0xff,0x00,0xff,0x4b,0xff,0x00,0xff,0x3a,0xff,
    0x00,0xff,0x29,0xff,0x00,0xff,0x13,0xff,0x00,0xff,0x02,0xff,0x00,0xff,0x00,0xff,
    0x0f,0xff,0x00,0xff,0x20,0xff,0x00,0xff,0x32,0xff,0x00,0xff,0x43,0xff,0x00,0xff,
    0x54,0xff,0x00,0xff,0x65,0xff,0x00,0xff,0x76,0xff,0x00,0xff,0x87,0xff,0x00,0xff,
    0x98,0xff,0x00,0xff,0xa9,0xff,0x00,0xff,0xba,0xff,0x00,0xff,0xcc,0xff,0x00,0xff,
    0xdc,0xff,0x00,0xff,0xee,0xff,0x00,0xff,0xff,0xff,0x00,0xff,0xff,0xff,0x00,0xff,
    0xff,0xff,0x00,0xff,0xff,0xff,0xff,0x00,0xff,0xff,0xfa,0x00,0xff,0xff,0xf3,0x00,
    0xff,0xff,0xea,0x00,0xff,0xff,0xe1,0x00,0xff,0xff,0xd8,0x00,0xff,0xff,0xd0,0x00,
    0xff,0xff,0xc7,0x00,0xff,0xff,0xbe,0x00,0xff,0xff,0xb6,0x00,0xff,0xff,0xae,0x00,
    0xff,0xff,0xa5,0x00,0xff,0xff,0x9d,0x00,0xff,0xff,0x94,0x00,0xff,0xff,0x8b,0x00,
    0xff,0xff,0x82,0x00,0xff,0xff,0x7a,0x00,0xff,0xff,0x72,0x00,0xff,0xff,0x69,0x00,
    0xff,0xff,0x60,0x00,0xff,0xff,0x58,0x00,0xff,0xff,0x50,0x00,0xff,0xff,0x47,0x00,
    0xff,0xff,0x3e,0x00,0xff,0xff,0x35,0x00,0xff,0xff,0x2d,0x00,0xff,0xff,0x24,0x00,
    0xff,0xff,0x1c,0x00,0xff,0xff,0x14,0x00,0xff,0xff,0x0b,0x00,0xff,0xff,0x02,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0xff,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0xff,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0xf6,0xff,0x00,0xff,0xe5,0xff,0x00,0xff,0xd4,0xff,0x00,0xff,0xc3,
    0xff,0x00,0xff,0xb1,0xff,0x00,0xff,0xa0,0xff,0x00,0xff,0x90,0xff,0x00,0xff,0x7f,
    0xff,0x00,0xff,0x6d,0xff,0x00,0xff,0x5c,0xff,0x00,0xff,0x4b,0xff,0x00,0xff,0x3a,
    0xff,0x00,0xff,0x29,0xff,0x00,0xff,0x14,0xff,0x00,0xff,0x02,0xff,0x00,0xff,0x00,
    0xff,0x0f,0xff,0x00,0xff,0x20,0xff,0x00,0xff,0x31,0xff,0x00,0xff,0x42,0xff,0x00,
    0xff,0x54,0xff,0x00,0xff,0x65,0xff,0x00,0xff,0x76,0xff,0x00,0xff,0x87,0xff,0x00,
    0xff,0x98,0xff,0x00,0xff,0xa9,0xff,0x00,0xff,0xba,0xff,0x00,0xff,0xcb,0xff,0x00,
    0xff,0xdd,0xff,0x00,0xff,0xee,0xff,0x00,0xff,0xff,0xff,0x00,0xff,0xff,0xff,0x00,
    0xff,0xff,0xff,0x00,0xff,0xff,0xff,0x00,0xff,0xff,0xfb,0x00,0xff,0xff,0xf2,0x00,
    0xff,0xff,0xea,0x00,0xff,0xff,0xe1,0x00,0xff,0xff,0xd8,0x00,0xff,0xff,0xd0,0x00,
    0xff,0xff,0xc7,0x00,0xff,0xff,0xbf,0x00,0xff,0xff,0xb6,0x00,0xff,0xff,0xae,0x00,
    0xff,0xff,0xa5,0x00,0xff,0xff,0x9d,0x00,0xff,0xff,0x94,0x00,0xff,0xff,0x8b,0x00,
    0xff,0xff,0x82,0x00,0xff,0xff,0x7a,0x00,0xff,0xff,0x72,0x00,0xff,0xff,0x69,0x00,
    0xff,0xff,0x60,0x00,0xff,0xff,0x58,0x00,0xff,0xff,0x4f,0x00,0xff,0xff,0x47,0x00,
    0xff,0xff,0x3e,0x00,0xff,0xff,0x35,0x00,0xff,0xff,0x2d,0x00,0xff,0xff,0x25,0x00,
    0xff,0xff,0x1c,0x00,0xff,0xff,0x13,0x00,0xff,0xff,0x0b,0x00,0xff,0xff,0x02,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0xff,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0xff,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0xf7,0xff,0x00,0xff,0xe5,0xff,0x00,0xff,0xd4,0xff,0x00,0xff,0xc3,
    0xff,0x00,0xff,0xb2,0xff,0x00,0xff,0xa1,0xff,0x00,0xff,0x90,0xff,0x00,0xff,0x7e,
    0xff,0x00,0xff,0x6e,0xff,0x00,0xff,0x5d,0xff,0x00,0xff,0x4b,0xff,0x00,0xff,0x3a,
    0xff,0x00,0xff,0x28,0xff,0x00,0xff,0x13,0xff,0x00,0xff,0x02,0xff,0x00,0xff,0x00,
    0xff,0x0f,0xff,0xff,0x00,0xff,0x20,0xff,0x00,0xff,0x31,0xff,0x00,0xff,0x43,0xff,
    0x00,0xff,0x54,0xff,0x00,0xff,0x65,0xff,0x00,0xff,0x76,0xff,0x00,0xff,0x87,0xff,
    0x00,0xff,0x98,0xff,0x00,0xff,0xaa,0xff,0x00,0xff,0xba,0xff,0x00,0xff,0xcb,0xff,
    0x00,0xff,0xdd,0xff,0x00,0xff,0xee,0xff,0x00,0xff,0xff,0xff,0x00,0xff,0xff,0xff,
    0x00,0xff,0xff,0xff,0x00,0xff,0xff,0xff,0x00,0xff,0xff,0xfb,0x00,0xff,0xff,0xf2,
    0x00,0xff,0xff,0xea,0x00,0xff,0xff,0xe1,0x00,0xff,0xff,0xd8,0x00,0xff,0xff,0xd0,
    0x00,0xff,0xff,0xc7,0x00,0xff,0xff,0xbf,0x00,0xff,0xff,0xb6,0x00,0xff,0xff,0xad,
    0x00,0xff,0xff,0xa5,0x00,0xff,0xff,0x9d,0x00,0xff,0xff,0x94,0x00,0xff,0xff,0x8b,
    0x00,0xff,0xff,0x83,0x00,0xff,0xff,0x7a,0x00,0xff,0xff,0x71,0x00,0xff,0xff,0x69,
    0x00,0xff,0xff,0x61,0x00,0xff,0xff,0x58,0x00,0xff,0xff,0x4f,0x00,0xff,0xff,0x47,
    0x00,0xff,0xff,0x3e,0x00,0xff,0xff,0x36,0x00,0xff,0xff,0x2d,0x00,0xff,0xff,0x25,
    0x00,0xff,0xff,0x1c,0x00,0xff,0xff,0x13,0x00,0xff,0xff,0x0a,0x00,0xff,0xff,0x02,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0xff,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0xff,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0xf7,0xff,0x00,0xff,0xe5,0xff,0x00,0xff,0xd4,0xff,0x00,0xff,
    0xc3,0xff,0x00,0xff,0xb2,0xff,0x00,0xff,0xa1,0xff,0x00,0xff,0x90,0xff,0x00,0xff,
    0x7e,0xff,0x00,0xff,0x6e,0xff,0x00,0xff,0x5c,0xff,0x00,0xff,0x4b,0xff,0x00,0xff,
    0x3a,0xff,0x00,0xff,0x29,0xff,0x00,0xff,0x14,0xff,0x00,0xff,0x02,0xff,0x00,0xff,
    0x00,0xff,0x0f,0xff,0x00,0xff,0x20,0xff,0x00,0xff,0x31,0xff,0x00,0xff,0x42,0xff,
    0x00,0xff,0x53,0xff,0x00,0xff,0x64,0xff,0x00,0xff,0x76,0xff,0x00,0xff,0x87,0xff,
    0x00,0xff,0x98,0xff,0x00,0xff,0xa9,0xff,0x00,0xff,0xbb,0xff,0x00,0xff,0xcc,0xff,
    0x00,0xff,0xdd,0xff,0x00,0xff,0xee,0xff,0x00,0xff,0xff,0xff,0x00,0xff,0xff,0xff,
    0x00,0xff,0xff,0xff,0x00,0xff,0xff,0xff,0x00,0xff,0xff,0xfb,0x00,0xff,0xff,0xf2,
    0x00,0xff,0xff,0xe9,0x00,0xff,0xff,0xe1,0x00,0xff,0xff,0xd9,0x00,0xff,0xff,0xd0,
    0x00,0xff,0xff,0xc7,0x00,0xff,0xff,0xbf,0x00,0xff,0xff,0xb6,0x00,0xff,0xff,0xad,
    0x00,0xff,0xff,0xa5,0x00,0xff,0xff,0x9d,0x00,0xff,0xff,0x94,0x00,0xff,0xff,0x8c,
    0x00,0xff,0xff,0x82,0x00,0xff,0xff,0x7a,0x00,0xff,0xff,0x72,0x00,0xff,0xff,0x69,
    0x00,0xff,0xff,0x61,0x00,0xff,0xff,0x58,0x00,0xff,0xff,0x4f,0x00,0xff,0xff,0x47,
    0x00,0xff,0xff,0x3e,0x00,0xff,0xff,0x36,0x00,0xff,0xff,0x2d,0x00,0xff,0xff,0x25,
    0x00,0xff,0xff,0x1c,0x00,0xff,0xff,0x13,0x00,0xff,0xff,0x0b,0x00,0xff,0xff,0x02,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0xff,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0xff,0x00,0x00,0x00,0x00,
    0xff,0x00,0x00,0x00,0x00,0xf6,0xff,0x00,0xff,0xe6,0xff,0x00,0xff,0xd4,0xff,0x00,
    0xff,0xc3,0xff,0x00,0xff,0xb1,0xff,0x00,0xff,0xa1,0xff,0x00,0xff,0x8f,0xff,0x00,
    0xff,0x7f,0xff,0x00,0xff,0x6e,0xff,0x00,0xff,0x5c,0xff,0x00,0xff,0x4b,0xff,0x00,
    0xff,0x3a,0xff,0x00,0xff,0x25,0xff,0x00,0xff,0x14,0xff,0x00,0xff,0x02,0xff,0x00,
    0xff,0x00,0xff,0x0f,0xff,0x00,0xff,0x20,0xff,0x00,0xff,0x31,0xff,0x00,0xff,0x42,
    0xff,0x00,0xff,0x54,0xff,0x00,0xff,0x65,0xff,0x00,0xff,0x76,0xff,0x00,0xff,0x87,
    0xff,0x00,0xff,0x98,0xff,0x00,0xff,0xa9,0xff,0x00,0xff,0xbb,0xff,0x00,0xff,0xcc,
    0xff,0x00,0xff,0xdc,0xff,0x00,0xff,0xee,0xff,0x00,0xff,0xff,0xff,0x00,0xff,0xff,
    0xff,0x00,0xff,0xff,0xff,0x00,0xff,0xff,0xff,0x00,0xff,0xff,0xfb,0x00,0xff,0xff,
    0xf2,0x00,0xff,0xff,0xe9,0x00,0xff,0xff,0xe1,0x00,0xff,0xff,0xd9,0x00,0xff,0xff,
    0xd0,0x00,0xff,0xff,0xc8,0x00,0xff,0xff,0xbe,0x00,0xff,0xff,0xb6,0x00,0xff,0xff,
    0xad,0x00,0xff,0xff,0xa5,0x00,0xff,0xff,0x9c,0x00,0xff,0xff,0x94,0x00,0xff,0xff,
    0x8b,0x00,0xff,0xff,0x83,0x00,0xff,0xff,0x7a,0x00,0xff,0xff,0x72,0x00,0xff,0xff,
    0x69,0x00,0xff,0xff,0x61,0x00,0xff,0xff,0x58,0x00,0xff,0xff,0x4f,0x00,0xff,0xff,
    0x47,0x00,0xff,0xff,0x3e,0x00,0xff,0xff,0x36,0x00,0xff,0xff,0x2d,0x00,0xff,0xff,
    0x24,0x00,0xff,0xff,0x1c,0x00,0xff,0xff,0x14,0x00,0xff,0xff,0x0a,0x00,0xff,0xff,
    0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0xff,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0xff,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0xf7,0xff,0x00,0xff,0xe6,0xff,0x00,0xff,0xd4,0xff,0x00,
    0xff,0xc3,0xff,0x00,0xff,0xb2,0xff,0x00,0xff,0xa1,0xff,0x00,0xff,0x8f,0xff,0x00,
    0xff,0x7e,0xff,0x00,0xff,0x6d,0xff,0x00,0xff,0x5c,0xff,0x00,0xff,0x4b,0xff,0x00,
    0xff,0x3a,0xff,0x00,0xff,0x24,0xff,0x00,0xff,0x13,0xff,0x00,0xff,0x02,0xff,0x00,
    0xff,0x00,0xff,0x0f,0xff,0x00,0xff,0x21,0xff,0x00,0xff,0x31,0xff,0x00,0xff,0x42,
    0xff,0x00,0xff,0x54,0xff,0x00,0xff,0x65,0xff,0x00,0xff,0x76,0xff,0x00,0xff,0x87,
    0xff,0x00,0xff,0x98,0xff,0x00,0xff,0xa9,0xff,0x00,0xff,0xba,0xff,0x00,0xff,0xcc,
    0xff,0x00,0xff,0xdc,0xff,0x00,0xff,0xee,0xff,0x00,0xff,0xff,0xff,0x00,0xff,0xff,
    0xff,0x00,0xff,0xff,0xff,0x00,0xff,0xff,0xff,0x00,0xff,0xff,0xfb,0x00,0xff,0xff,
    0xf2,0x00,0xff,0xff,0xea,0x00,0xff,0xff,0xe1,0x00,0xff,0xff,0xd9,0x00,0xff,0xff,
    0xd0,0x00,0xff,0xff,0xc7,0x00,0xff,0xff,0xbf,0x00,0xff,0xff,0xb6,0x00,0xff,0xff,
    0xae,0x00,0xff,0xff,0xa5,0x00,0xff,0xff,0x9c,0x00,0xff,0xff,0x94,0x00,0xff,0xff,
    0x8c,0x00,0xff,0xff,0x83,0x00,0xff,0xff,0x7a,0x00,0xff,0xff,0x72,0x00,0xff,0xff,
    0x69,0x00,0xff,0xff,0x61,0x00,0xff,0xff,0x58,0x00,0xff,0xff,0x4f,0xff,0x00,0xff,
    0xff,0x47,0x00,0xff,0xff,0x3e,0x00,0xff,0xff,0x36,0x00,0xff,0xff,0x2d,0x00,0xff,
    0xff,0x25,0x00,0xff,0xff,0x1c,0x00,0xff,0xff,0x13,0x00,0xff,0xff,0x0b,0x00,0xff,
    0xff,0x02,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0xff,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0xff,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0xf7,0xff,0x00,0xff,0xe5,0xff,0x00,0xff,0xd4,0xff,
    0x00,0xff,0xc3,0xff,0x00,0xff,0xb2,0xff,0x00,0xff,0xa0,0xff,0x00,0xff,0x8f,0xff,
    0x00,0xff,0x7e,0xff,0x00,0xff,0x6d,0xff,0x00,0xff,0x5c,0xff,0x00,0xff,0x4b,0xff,
    0x00,0xff,0x3a,0xff,0x00,0xff,0x24,0xff,0x00,0xff,0x14,0xff,0x00,0xff,0x02,0xff,
    0x00,0xff,0x00,0xff,0x0f,0xff,0x00,0xff,0x21,0xff,0x00,0xff,0x32,0xff,0x00,0xff,
    0x43,0xff,0x00,0xff,0x54,0xff,0x00,0xff,0x64,0xff,0x00,0xff,0x75,0xff,0x00,0xff,
    0x87,0xff,0x00,0xff,0x98,0xff,0x00,0xff,0xa9,0xff,0x00,0xff,0xba,0xff,0x00,0xff,
    0xcc,0xff,0x00,0xff,0xdd,0xff,0x00,0xff,0xee,0xff,0x00,0xff,0xff,0xff,0x00,0xff,
    0xff,0xff,0x00,0xff,0xff,0xff,0x00,0xff,0xff,0xff,0x00,0xff,0xff,0xfa,0x00,0xff,
    0xff,0xf2,0x00,0xff,0xff,0xea,0x00,0xff,0xff,0xe1,0x00,0xff,0xff,0xd9,0x00,0xff,
    0xff,0xcf,0x00,0xff,0xff,0xc7,0x00,0xff,0xff,0xbf,0x00,0xff,0xff,0xb6,0x00,0xff,
    0xff,0xae,0x00,0xff,0xff,0xa5,0x00,0xff,0xff,0x9c,0x00,0xff,0xff,0x94,0x00,0xff,
    0xff,0x8b,0x00,0xff,0xff,0x83,0x00,0xff,0xff,0x7a,0x00,0xff,0xff,0x71,0x00,0xff,
    0xff,0x69,0x00,0xff,0xff,0x61,0x00,0xff,0xff,0x58,0x00,0xff,0xff,0x4f,0x00,0xff,
    0xff,0x46,0x00,0xff,0xff,0x3e,0x00,0xff,0xff,0x35,0x00,0xff,0xff,0x2d,0x00,0xff,
    0xff,0x24,0x00,0xff,0xff,0x1c,0x00,0xff,0xff,0x13,0x00,0xff,0xff,0x0a,0x00,0xff,
    0xff,0x02,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0xff,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0xff,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0xf6,0xff,0x00,0xff,0xe5,0xff,0x00,0xff,0xd4,0xff,
    0x00,0xff,0xc3,0xff,0x00,0xff,0xb2,0xff,0x00,0xff,0xa0,0xff,0x00,0xff,0x8f,0xff,
    0x00,0xff,0x7f,0xff,0x00,0xff,0x6d,0xff,0x00,0xff,0x5c,0xff,0x00,0xff,0x4b,0xff,
    0x00,0xff,0x36,0xff,0x00,0xff,0x24,0xff,0x00,0xff,0x14,0xff,0x00,0xff,0x02,0xff,
    0x00,0xff,0x00,0xff,0x0f,0xff,0x00,0xff,0x20,0xff,0x00,0xff,0x31,0xff,0x00,0xff,
    0x42,0xff,0x00,0xff,0x53,0xff,0x00,0xff,0x65,0xff,0x00,0xff,0x76,0xff,0x00,0xff,
    0x87,0xff,0x00,0xff,0x98,0xff,0x00,0xff,0xa9,0xff,0x00,0xff,0xba,0xff,0x00,0xff,
    0xcc,0xff,0x00,0xff,0xdd,0xff,0x00,0xff,0xee,0xff,0x00,0xff,0xff,0xff,0x00,0xff,
    0xff,0xff,0x00,0xff,0xff,0xff,0x00,0xff,0xff,0xff,0x00,0xff,0xff,0xfa,0x00,0xff,
    0xff,0xf2,0x00,0xff,0xff,0xe9,0x00,0xff,0xff,0xe1,0xff,0x00,0xff,0xff,0xd9,0x00,
    0xff,0xff,0xd0,0x00,0xff,0xff,0xc7,0x00,0xff,0xff,0xbf,0x00,0xff,0xff,0xb6,0x00,
    0xff,0xff,0xae,0x00,0xff,0xff,0xa5,0x00,0xff,0xff,0x9d,0x00,0xff,0xff,0x94,0x00,
    0xff,0xff,0x8b,0x00,0xff,0xff,0x82,0x00,0xff,0xff,0x7a,0x00,0xff,0xff,0x72,0x00,
    0xff,0xff,0x69,0x00,0xff,0xff,0x60,0x00,0xff,0xff,0x58,0x00,0xff,0xff,0x4f,0x00,
    0xff,0xff,0x46,0x00,0xff,0xff,0x3f,0x00,0xff,0xff,0x35,0x00,0xff,0xff,0x2d,0x00,
    0xff,0xff,0x24,0x00,0xff,0xff,0x1c,0x00,0xff,0xff,0x13,0x00,0xff,0xff,0x0b,0x00,
    0xff,0xff,0x02,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0xff,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0xff,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf6,0xff,0x00,0xff,0xe6,0xff,0x00,0xff,0xd5,
    0xff,0x00,0xff,0xc3,0xff,0x00,0xff,0xb2,0xff,0x00,0xff,0xa0,0xff,0x00,0xff,0x90,
    0xff,0x00,0xff,0x7f,0xff,0x00,0xff,0x6e,0xff,0x00,0xff,0x5c,0xff,0x00,0xff,0x4b,
    0xff,0x00,0xff,0x35,0xff,0x00,0xff,0x24,0xff,0x00,0xff,0x13,0xff,0x00,0xff,0x02,
    0xff,0x00,0xff,0x00,0xff,0x0f,0xff,0x00,0xff,0x20,0xff,0x00,0xff,0x32,0xff,0x00,
    0xff,0x42,0xff,0x00,0xff,0x53,0xff,0x00,0xff,0x64,0xff,0x00,0xff,0x75,0xff,0x00,
    0xff,0x87,0xff,0x00,0xff,0x98,0xff,0x00,0xff,0xa9,0xff,0x00,0xff,0xba,0xff,0x00,
    0xff,0xcb,0xff,0x00,0xff,0xdc,0xff,0x00,0xff,0xee,0xff,0x00,0xff,0xff,0xff,0x00,
    0xff,0xff,0xff,0x00,0xff,0xff,0xff,0x00,0xff,0xff,0xff,0x00,0xff,0xff,0xfb,0x00,
    0xff,0xff,0xf2,0x00,0xff,0xff,0xe9,0x00,0xff,0xff,0xe1,0x00,0xff,0xff,0xd8,0x00,
    0xff,0xff,0xd0,0x00,0xff,0xff,0xc7,0x00,0xff,0xff,0xbf,0x00,0xff,0xff,0xb6,0x00,
    0xff,0xff,0xad,0x00,0xff,0xff,0xa5,0x00,0xff,0xff,0x9d,0x00,0xff,0xff,0x93,0x00,
    0xff,0xff,0x8c,0x00,0xff,0xff,0x83,0x00,0xff,0xff,0x7a,0x00,0xff,0xff,0x72,0x00,
    0xff,0xff,0x69,0x00,0xff,0xff,0x60,0x00,0xff,0xff,0x58,0x00,0xff,0xff,0x50,0x00,
    0xff,0xff,0x46,0x00,0xff,0xff,0x3e,0x00,0xff,0xff,0x36,0x00,0xff,0xff,0x2d,0x00,
    0xff,0xff,0x24,0x00,0xff,0xff,0x1c,0x00,0xff,0xff,0x13,0x00,0xff,0xff,0x0b,0x00,
    0xff,0xff,0x02,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0xff,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0xff,0x00,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf6,0xff,0x00,0xff,0xe6,0xff,0x00,0xff,0xd4,
    0xff,0x00,0xff,0xc3,0xff,0x00,0xff,0xb1,0xff,0x00,0xff,0xa1,0xff,0x00,0xff,0x8f,
    0xff,0x00,0xff,0x7e,0xff,0x00,0xff,0x6d,0xff,0x00,0xff,0x5c,0xff,0x00,0xff,0x4b,
    0xff,0x00,0xff,0x35,0xff,0x00,0xff,0x24,0xff,0x00,0xff,0x13,0xff,0x00,0xff,0x02,
    0xff,0x00,0xff,0x00,0xff,0x0f,0xff,0x00,0xff,0x20,0xff,0x00,0xff,0x32,0xff,0x00,
    0xff,0x42,0xff,0x00,0xff,0x54,0xff,0xfb,0x00,0xff,0x65,0xff,0x00,0xff,0x76,0xff,
    0x00,0xff,0x87,0xff,0x00,0xff,0x98,0xff,0x00,0xff,0xa9,0xff,0x00,0xff,0xba,0xff,
    0x00,0xff,0xcb,0xff,0x00,0xff,0xdd,0xff,0x00,0xff,0xee,0xff,0x00,0xff,0xff,0xff,
    0x00,0xff,0xff,0xff,0x00,0xff,0xff,0xff,0x00,0xff,0xff,0xff,0x00,0xff,0xff,0xfa,
    0x00,0xff,0xff,0xf2,0x00,0xff,0xff,0xea,0x00,0xff,0xff,0xe1,0x00,0xff,0xff,0xd8,
    0x00,0xff,0xff,0xd0,0x00,0xff,0xff,0xc7,0x00,0xff,0xff,0xbf,0x00,0xff,0xff,0xb6,
    0x00,0xff,0xff,0xae,0x00,0xff,0xff,0xa5,0x00,0xff,0xff,0x9d,0x00,0xff,0xff,0x94,
    0x00,0xff,0xff,0x8c,0x00,0xff,0xff,0x83,0x00,0xff,0xff,0x7a,0x00,0xff,0xff,0x72,
    0x00,0xff,0xff,0x69,0x00,0xff,0xff,0x61,0x00,0xff,0xff,0x58,0x00,0xff,0xff,0x4f,
    0x00,0xff,0xff,0x47,0x00,0xff,0xff,0x3e,0x00,0xff,0xff,0x36,0x00,0xff,0xff,0x2d,
    0x00,0xff,0xff,0x24,0x00,0xff,0xff,0x1c,0x00,0xff,0xff,0x13,0x00,0xff,0xff,0x0b,
    0x00,0xff,0xff,0x02,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0xff,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0xff,
    0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xf6,0xff,0x00,0xff,0xe5,0xff,0x00,0xff,
    0xd4,0xff,0x00,0xff,0xc3,0xff,0x00,0xff,0xb2,0xff,0x00,0xff,0xa1,0xff,0x00,0xff,
    0x90,0xff,0x00,0xff,0x7e,0xff,0x00,0xff,0x6d,0xff,0x00,0xff,0x5c,0xff,0x00,0xff,
    0x47,0xff,0x00,0xff,0x36,0xff,0x00,0xff,0x25,0xff,0x00,0xff,0x13,0xff,0x00,0xff,
    0x02,0xff,0x00,0xff,0x00,0xff,0x0f,0xff,0x00,0xff,0x20,0xff,0x00,0xff,0x32,0xff,
    0x00,0xff,0x42,0xff,0x00,0xff,0x54,0xff,0x00,0xff,0x64,0xff,0x00,0xff,0x76,0xff,
    0x00,0xff,0x87,0xff,0x00,0xff,0x99,0xff,0x00,0xff,0xaa,0xff,0x00,0xff,0xba,0xff,
    0x00,0xff,0xcc,0xff,0x00,0xff,0xdd,0xff,0x00,0xff,0xee,0xff,0x00,0xff,0xff,0xff,
    0x00,0xff,0xff,0xff,0x00,0xff,0xff,0xff,0x00,0xff,0xff,0xff,0x00,0xff,0xff,0xfb,
    0x00,0xff,0xff,0xf2,0x00,0xff,0xff,0xea,0x00,0xff,0xff,0xe1,0x00,0xff,0xff,0xd9,
    0x00,0xff,0xff,0xd0,0x00,0xff,0xff,0xc7,0x00,0xff,0xff,0xbf,0x00,0xff,0xff,0xb6,
    0x00,0xff,0xff,0xae,0x00,0xff,0xff,0xa5,0x00,0xff,0xff,0x9c,0x00,0xff,0xff,0x94,
    0x00,0xff,0xff,0x8c,0x00,0xff,0xff,0x83,0x00,0xff,0xff,0x7a,0x00,0xff,0xff,0x72,
    0x00,0xff,0xff,0x69,0x00,0xff,0xff,0x60,0x00,0xff,0xff,0x57,0x00,0xff,0xff,0x50,
    0x00,0xff,0xff,0x47,0x00,0xff,0xff,0x3f,0x00,0xff,0xff,0x36,0x00,0xff,0xff,0x2d,
    0x00,0xff,0xff,0x24,0x00,0xff,0xff,0x1c,0x00,0xff,0xff,0x13,0x00,0xff,0xff,0x0a,
    0x00,0xff,0xff,0x02,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
    0x00,0x00,0x00,0x00,0x00,0xff,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0xff,
    0x00,0x00,0x00,0x00,0x44,0x00,0x00,0x00,0x00,0x84,0x00,0xff,0x00,0xff,0x00,0x00,
    0x00,0x00,0x00,0xff,0x00,0xff,0x00,0x00,0x00,0x00,0x44,0x00,0x00,0x00,0x00,0x84,
    0x00,0xff,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0xff,0x00,0xff,0x00,0x00,0x00,0x00,
    0x44,0x00,0x00,0x00,0x00,0x83,0x00,0xff,0x00,0xff,0x00,0x00,0x00,0x00,0x00,0xff,
    0x00,0xff,0x46,0x00,0xff,0x00,0xff,0x81,0x00,0x00,0x00,0x00,

};

const lv_image_dsc_t test_ARGB8888_RLE_align64 = {
  .header = {
    .magic = LV_IMAGE_HEADER_MAGIC,
    .cf = LV_COLOR_FORMAT_ARGB8888,
    .flags = 0 | LV_IMAGE_FLAGS_COMPRESSED,
    .w = 71,
    .h = 60,
    .stride = 288,
    .reserved_2 = 0,
  },
  .data_size = sizeof(test_ARGB8888_RLE_align64_map),
  .data = test_ARGB8888_RLE_align64_map,
  .reserved = NULL,
};

